<?php
/*
Advertisement_Widget
*/
class Advertisement_Widget  extends WP_Widget {
    function __construct() {
        parent::__construct(
        'sn_advertisement', // Base ID
        __( 'Ad Banner', 'softnep_news' ), // Name
        array( 'description' => __( 'Widget for displaying ads in sidebars', 'softnep_news' ) )
        );
    }
     /**
    * Front-end display of widget.
    */
    function widget( $args, $instance ) {
        extract( $args );
        $title  =  apply_filters('widget_title', $instance['title']) ;
        $adcode = !empty( $instance['adcode'] ) ? $instance[ 'adcode' ] : '';
        $image  = !empty( $instance['image'] ) ? $instance[ 'image' ] : '';
        $href   = !empty( $instance['href'] ) ? $instance[ 'href' ] : '';
        $target = !empty( $instance['target'] ) ? 'true' : 'false';
        $alt    = !empty( $instance['alt'] ) ? $instance[ 'alt' ] : '';
        if ( $adcode != '' ) {
            echo '<div id="sn_advert">
                    <div class="advert">
                    <div class="block">';
            echo $adcode;
            echo '</div> </div> </div>';
        }
        else {
            echo  '<div id="sn_advert">
                    <div class="advert">
                    <div class="block">';
            if($href==''){
                echo '<a href="javascript:void(0)"';
                echo '><img src="'. esc_url($image) . '" alt="' . esc_attr( $alt ) . '" /></a>';
               
            }else{
            echo '<a href="' . esc_url($href) . '" ';
            echo ($target)?' target="_blank"':'';
            echo ' ><img src="'. esc_url($image) . '" alt="' . esc_attr( $alt ) . '" /></a>';
            }
        echo '</div> </div> </div>';
        }
    }
    /**
    * Sanitize widget form values as they are saved.
   * @return array Updated safe values to be saved.
    */
    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title']  =   esc_attr( strip_tags($new_instance['title']) );
        $instance['adcode'] = wp_kses_stripslashes($new_instance['adcode']);
        $instance['image']  = esc_url_raw($new_instance['image']);
        $instance['href']   = esc_url_raw($new_instance['href']);
        $instance['target'] = !empty($new_instance['target']) ? 1 : 0;
        $instance['alt']    = sanitize_text_field($new_instance['alt']);
        return $instance;
    }
     /**
    * Create the form for the Widget admin
     *
    * @param array $instance Previously saved values from database.
    */
    function form( $instance ) {
        $instance = wp_parse_args( (array) $instance, array(
            'title'  => '',
            'adcode' => '',
            'image'  => '',
            'href'   => '',
            'target' => 0,
            'alt'    => ''
            )
        );
        $title  =   isset($instance['title']) ? esc_attr($instance['title']) : '';
        $adcode =   isset($instance['adcode']) ? esc_textarea($instance['adcode']) : '';
        $image  =   isset($instance['image']) ? esc_url($instance['image']) : '';
        $href   =   isset($instance['href']) ? esc_url($instance['href']) : '';
        $target =   isset($instance['target']) ? esc_attr($instance['target']) : '';
        $alt    =   isset($instance['alt']) ? esc_attr($instance['alt']) : '';
?>
    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'softnep_news'); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title ; ?>" />
    </p>
    <hr/>
    <?php if ( current_user_can( 'unfiltered_html' ) ) : ?>
        <p>
            <label for="<?php echo $this->get_field_id('adcode'); ?>"><?php _e('Adv Code:','softnep_news'); ?></label>
            <textarea name="<?php echo $this->get_field_name('adcode'); ?>" class="widefat" id="<?php echo $this->get_field_id('adcode'); ?>"><?php echo $adcode; ?></textarea><small><?php _e('eg, Google Ad code','softnep_news'); ?></small>
        </p>
    <?php endif; ?>
    <hr >
    <p style="text-align:center;"><strong>OR</strong></p>
    <hr >
    <p>
        <label for="<?php echo $this->get_field_id('image'); ?>"><?php _e('Image URL:','softnep_news'); ?></label>
        <input type="text" name="<?php echo $this->get_field_name('image'); ?>" value="<?php echo $image; ?>" class="widefat custom_media_url" id="<?php echo $this->get_field_id('image'); ?>" />
    </p>
    <p>
        <input type="button" value="<?php _e( 'Upload Image', 'softnep_news' ); ?>" class="button custom_media_upload" id="custom_image_uploader"/>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('href'); ?>"><?php _e('Link URL:','softnep_news'); ?></label>
        <input type="text" name="<?php echo $this->get_field_name('href'); ?>" value="<?php echo esc_url( $href ); ?>" class="widefat" id="<?php echo $this->get_field_id('href'); ?>" />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('target'); ?>"><?php _e( 'Open Link in New Window', 'softnep_news' ); ?></label>
        <input id="<?php echo $this->get_field_id('target'); ?>" name="<?php echo $this->get_field_name('target'); ?>" type="checkbox" <?php checked(isset($instance['target']) ? $instance['target'] : 0); ?> />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('alt'); ?>"><?php _e('Alt text:','softnep_news'); ?></label>
        <input type="text" name="<?php echo $this->get_field_name('alt'); ?>" value="<?php echo $alt; ?>" class="widefat" id="<?php echo $this->get_field_id('alt'); ?>" />
    </p>
<?php }
}
function softnep_banner_upload_script(){
  wp_enqueue_media();
  wp_register_script( 'image-upload-widget', get_template_directory_uri()  . '/js/image-upload-widget.js');
  wp_enqueue_script( 'image-upload-widget' );
}
add_action('admin_enqueue_scripts', 'softnep_banner_upload_script');
//register widget
function register_ad_widget() {
    register_widget( 'Advertisement_Widget' );
}
add_action( 'widgets_init', 'register_ad_widget' );

/*
Header_Advertisement_Widget
*/
class Header_Advertisement_Widget  extends WP_Widget {
    function __construct() {
        parent::__construct(
        'sn_header_advertisement', // Base ID
        __( 'Header Ad Banner 470X60', 'softnep_news' ), // Name
        array( 'description' => __( 'Widget for displaying ads in header of 468px X 60px', 'softnep_news' ) )
        );
    }
     /**
    * Front-end display of widget.
     */
    function widget( $args, $instance ) {
        extract( $args );
        $title  =  apply_filters('widget_title', $instance['title']) ;
        $adcode = !empty( $instance['adcode'] ) ? $instance[ 'adcode' ] : '';
        $image  = !empty( $instance['image'] ) ? $instance[ 'image' ] : '';
        $href   = !empty( $instance['href'] ) ? $instance[ 'href' ] : '';
        $target = !empty( $instance['target'] ) ? 'true' : 'false';
        $alt    = !empty( $instance['alt'] ) ? $instance[ 'alt' ] : '';
        if ( $adcode != '' ) {
            echo '<div class="googlead">';
            echo $adcode;
            echo '</div>';
        }
        else {
           echo '<div class="googlead">';
           if ($href==''){
            echo '<a href="javascript:void(0)"';
            echo ' ><img src="'. esc_url($image) . '" alt="' . esc_attr( $alt ) . '" /></a>';
           }else {
            echo '<a href="' . esc_url($href) . '" ';              
            echo ($target)?' target="_blank"':'';
            echo ' ><img src="'. esc_url($image) . '" alt="' . esc_attr( $alt ) . '" /></a>';
            }
        echo '</div>';
        }
    }
    /**
    * Sanitize widget form values as they are saved.
   * @return array Updated safe values to be saved.
    */
    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title']  =   esc_attr( strip_tags($new_instance['title']) );
        $instance['adcode'] = wp_kses_stripslashes($new_instance['adcode']);
        $instance['image']  = esc_url_raw($new_instance['image']);
        $instance['href']   = esc_url_raw($new_instance['href']);
        $instance['target'] = !empty($new_instance['target']) ? 1 : 0;
        $instance['alt']    = sanitize_text_field($new_instance['alt']);
        return $instance;
    }
     /**
    * Create the form for the Widget admin
     *
    * @param array $instance Previously saved values from database.
    */
    function form( $instance ) {
        $instance = wp_parse_args( (array) $instance, array(
            'title'  => '',
            'adcode' => '',
            'image'  => '',
            'href'   => '',
            'target' => 0,
            'alt'    => ''
            )
        );
        $title  =   isset($instance['title']) ? esc_attr($instance['title']) : '';
        $adcode =   isset($instance['adcode']) ? esc_textarea($instance['adcode']) : '';
        $image  =   isset($instance['image']) ? esc_url($instance['image']) : '';
        $href   =   isset($instance['href']) ? esc_url($instance['href']) : '';
        $target =   isset($instance['target']) ? esc_attr($instance['target']) : '';
        $alt    =   isset($instance['alt']) ? esc_attr($instance['alt']) : '';
?>
    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'softnep_news'); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title ; ?>" />
    </p>
    <hr/>
    <?php if ( current_user_can( 'unfiltered_html' ) ) : ?>
        <p>
            <label for="<?php echo $this->get_field_id('adcode'); ?>"><?php _e('Adv Code:','softnep_news'); ?></label>
            <textarea name="<?php echo $this->get_field_name('adcode'); ?>" class="widefat" id="<?php echo $this->get_field_id('adcode'); ?>"><?php echo $adcode; ?></textarea><small><?php _e('eg, Google Ad code','softnep_news'); ?></small>
        </p>
    <?php endif; ?>
    <hr >
    <p style="text-align:center;"><strong>OR</strong></p>
    <hr >
    <p>
        <label for="<?php echo $this->get_field_id('image'); ?>"><?php _e('Image URL:','softnep_news'); ?></label>
        <input type="text" name="<?php echo $this->get_field_name('image'); ?>" value="<?php echo $image; ?>" class="widefat custom_media_url" id="<?php echo $this->get_field_id('image'); ?>" />
    </p>
    <p>
        <input type="button" value="<?php _e( 'Upload Image', 'softnep_news' ); ?>" class="button custom_media_upload" id="custom_image_uploader"/>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('href'); ?>"><?php _e('Link URL:','softnep_news'); ?></label>
        <input type="text" name="<?php echo $this->get_field_name('href'); ?>" value="<?php echo esc_url( $href ); ?>" class="widefat" id="<?php echo $this->get_field_id('href'); ?>" />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('target'); ?>"><?php _e( 'Open Link in New Window', 'softnep_news' ); ?></label>
        <input id="<?php echo $this->get_field_id('target'); ?>" name="<?php echo $this->get_field_name('target'); ?>" type="checkbox" <?php checked(isset($instance['target']) ? $instance['target'] : 0); ?> />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('alt'); ?>"><?php _e('Alt text:','softnep_news'); ?></label>
        <input type="text" name="<?php echo $this->get_field_name('alt'); ?>" value="<?php echo $alt; ?>" class="widefat" id="<?php echo $this->get_field_id('alt'); ?>" />
    </p>
<?php }
}
//register widget
function register_header_ad_widget() {
    register_widget( 'Header_Advertisement_Widget' );
}
add_action( 'widgets_init', 'register_header_ad_widget' );

/*
Large Size Advertisement Widget
*/
class Large_Advertisement_Widget  extends WP_Widget {
    function __construct() {
        parent::__construct(
            'sn_large_advertisement',       // Base ID
            'Banner Ad 970X90',          // Name
         array(
                'classname'     =>   'facebook_widget',
                'description'   =>   __( 'Widget for displaying ads of 970px X 90px below header and above footer ', 'softnep_news' )
            )
        );
    }
     /**
    * Front-end display of widget.
    */
    function widget( $args, $instance ) {
        extract( $args );
        $title  =   apply_filters('widget_title', $instance['title']) ;
        $adcode = !empty( $instance['adcode'] ) ? $instance[ 'adcode' ] : '';
        $image  = !empty( $instance['image'] ) ? $instance[ 'image' ] : '';
        $href   = !empty( $instance['href'] ) ? $instance[ 'href' ] : '';
        $target = !empty( $instance['target'] ) ? 'true' : 'false';
        $alt    = !empty( $instance['alt'] ) ? $instance[ 'alt' ] : '';
        if ( $adcode != '' ) {
            echo '<div id="sn_page">
            <div class="advert">
            <div class="block">';
            echo $adcode;
            echo '</div> </div> </div>';
        }
        else {
           echo '<div id="sn_page">
            <div class="advert">
            <div class="block">';
            if($href==''){
            echo '<a href="javascript:void(0)"';
            echo ' ><img src="'. esc_url($image) . '" alt="' . esc_attr( $alt ) . '" /></a>';
            }else {
            echo '<a href="' . esc_url($href) . '" ';
            echo ($target)?' target="_blank"':'';
            echo ' ><img src="'. esc_url($image) . '" alt="' . esc_attr( $alt ) . '" /></a>';
            }
        echo '</div> </div></div>';
        }
    }
    /**
    * Sanitize widget form values as they are saved.
   * @return array Updated safe values to be saved.
    */
    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title']  =   esc_attr( strip_tags($new_instance['title']) );
        $instance['adcode'] = wp_kses_stripslashes($new_instance['adcode']);
        $instance['image']  = esc_url_raw($new_instance['image']);
        $instance['href']   = esc_url_raw($new_instance['href']);
        $instance['target'] = !empty($new_instance['target']) ? 1 : 0;
        $instance['alt']    = sanitize_text_field($new_instance['alt']);
        return $instance;
    }
     /**
    * Create the form for the Widget admin
     *
    * @param array $instance Previously saved values from database.
    */
    function form( $instance ) {
        $instance = wp_parse_args( (array) $instance, array(
            'title'  => '',
            'adcode' => '',
            'image'  => '',
            'href'   => '',
            'target' => 0,
            'alt'    => ''
            )
        );
        $title  =   isset($instance['title']) ? esc_attr($instance['title']) : '';
        $adcode =   isset($instance['adcode']) ? esc_textarea($instance['adcode']) : '';
        $image  =   isset($instance['image']) ? esc_url($instance['image']) : '';
        $href   =   isset($instance['href']) ? esc_url($instance['href']) : '';
        $target =   isset($instance['target']) ? esc_attr($instance['target']) : '';
        $alt    =   isset($instance['alt']) ? esc_attr($instance['alt']) : '';
?>
    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'softnep_news'); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title ; ?>" />
    </p>
    <hr/>
    <?php if ( current_user_can( 'unfiltered_html' ) ) : ?>
        <p>
            <label for="<?php echo $this->get_field_id('adcode'); ?>"><?php _e('Adv Code:','softnep_news'); ?></label>
            <textarea name="<?php echo $this->get_field_name('adcode'); ?>" class="widefat" id="<?php echo $this->get_field_id('adcode'); ?>"><?php echo $adcode; ?></textarea><small><?php _e('eg, Google Ad code','softnep_news'); ?></small>
        </p>
    <?php endif; ?>
    <hr >
    <p style="text-align:center;"><strong>OR</strong></p>
    <hr >
    <p>
        <label for="<?php echo $this->get_field_id('image'); ?>"><?php _e('Image URL:','softnep_news'); ?></label>
        <input type="text" name="<?php echo $this->get_field_name('image'); ?>" value="<?php echo $image; ?>" class="widefat custom_media_url" id="<?php echo $this->get_field_id('image'); ?>" />
    </p>
    <p>
        <input type="button" value="<?php _e( 'Upload Image', 'softnep_news' ); ?>" class="button custom_media_upload" id="custom_image_uploader"/>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('href'); ?>"><?php _e('Link URL:','softnep_news'); ?></label>
        <input type="text" name="<?php echo $this->get_field_name('href'); ?>" value="<?php echo esc_url( $href ); ?>" class="widefat" id="<?php echo $this->get_field_id('href'); ?>" />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('target'); ?>"><?php _e( 'Open Link in New Window', 'softnep_news' ); ?></label>
        <input id="<?php echo $this->get_field_id('target'); ?>" name="<?php echo $this->get_field_name('target'); ?>" type="checkbox" <?php checked(isset($instance['target']) ? $instance['target'] : 0); ?> />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('alt'); ?>"><?php _e('Alt text:','softnep_news'); ?></label>
        <input type="text" name="<?php echo $this->get_field_name('alt'); ?>" value="<?php echo $alt; ?>" class="widefat" id="<?php echo $this->get_field_id('alt'); ?>" />
    </p>
<?php }
}
//register widget
function register_large_ad_widget() {
    register_widget( 'Large_Advertisement_Widget' );
}
add_action( 'widgets_init', 'register_large_ad_widget' );